==> kubernetes-model-networking-5.7.3-sources.jar: io/fabric8/kubernetes/api/model/networking/v1beta1/IngressClassSpecFluent.java <==
package io.fabric8.kubernetes.api.model.networking.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface IngressClassSpecFluent<A extends io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getController();
  public A withController(java.lang.String controller);
  public java.lang.Boolean hasController();
  
  /**
   * Method is deprecated. use withController instead.
   */
  @java.lang.Deprecated
  public A withNewController(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildParameters instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReference getParameters();
  public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReference buildParameters();
  public A withParameters(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReference parameters);
  public java.lang.Boolean hasParameters();
  public A withNewParameters(java.lang.String apiGroup,java.lang.String kind,java.lang.String name,java.lang.String namespace,java.lang.String scope);
  public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent.ParametersNested<A> withNewParameters();
  public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent.ParametersNested<A> withNewParametersLike(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReference item);
  public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent.ParametersNested<A> editParameters();
  public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent.ParametersNested<A> editOrNewParameters();
  public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent.ParametersNested<A> editOrNewParametersLike(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReference item);
  public interface ParametersNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReferenceFluent<io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent.ParametersNested<N>>{
    public N and();
    public N endParameters();
    
  }
  
}

==> kubernetes-model-networking-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/networking/v1beta1/IngressClassSpecFluent.java <==
package io.fabric8.kubernetes.api.model.networking.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface IngressClassSpecFluent<A extends io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getController();
  public A withController(java.lang.String controller);
  public java.lang.Boolean hasController();
  
  /**
   * Method is deprecated. use withController instead.
   */
  @java.lang.Deprecated
  public A withNewController(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildParameters instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReference getParameters();
  public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReference buildParameters();
  public A withParameters(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReference parameters);
  public java.lang.Boolean hasParameters();
  public A withNewParameters(java.lang.String apiGroup,java.lang.String kind,java.lang.String name,java.lang.String namespace,java.lang.String scope);
  public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent.ParametersNested<A> withNewParameters();
  public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent.ParametersNested<A> withNewParametersLike(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReference item);
  public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent.ParametersNested<A> editParameters();
  public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent.ParametersNested<A> editOrNewParameters();
  public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent.ParametersNested<A> editOrNewParametersLike(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReference item);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface ParametersNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReferenceFluent<io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent.ParametersNested<N>>{
    public N and();
    public N endParameters();
    
  }
  
}
